// Auth types
export interface LoginRequest {
  email: string
  password: string
}

export interface LoginResponse {
  ID: string
  Email: string
}

export interface RegisterRequest {
  email: string
  password: string
}

export interface RegisterResponse {
  ID: string
  Email: string
}

// Validation types
export interface Ticket {
  ticket_id: string
  client_id: string
  email: string
  phone: string
  name: string
  client_type?: string
  last_update: string
  description?: string
  status: string
}

export interface TicketInfo {
  ticket_id: string
  client_id: string
  last_update: string
  description?: string
  status: string
}

export interface GetValidationTicketsRequest {
  statusFilter?: string
  clientTypeFilter?: string
  sortFilter?: string
  page?: number
  pageSize?: number
}

export interface GetValidationTicketsResponse {
  tickets: Ticket[]
}

export interface GetValidationTicketByIdRequest {
  ticket_id: string
}

export interface GetValidationTicketByIdResponse {
  ticket: Ticket
}

export interface UpdateValidationStatusByTicketIdRequest {
  old_status: string
  new_status: string
  corrections?: string
}

export interface UpdateValidationStatusByTicketIdResponse {
  ticket_info: TicketInfo
}

// Company validation types
export interface CompanyValidationTicket {
  id: string
  name: string
  owner: string
  email: string
  type: string
  status: string
  date: string
  documents: string[]
}

// Dashboard types
export interface DashboardStats {
  pendingTickets: number
  pendingCompanies: number
  pendingUsers: number
  activeUsers: number
}

export interface DashboardData {
  stats: DashboardStats
  recentTickets: Ticket[]
  pendingCompanies: CompanyValidationTicket[]
}

// Vacancy types
export interface Vacancy {
  id: string
  title: string
  company: string
  description: string
  requirements: string[]
  responsibilities: string[]
  location: string
  salary_range: {
    min: number
    max: number
    currency: string
  }
  employment_type: string
  experience_level: string
  agent_reward?: number
  status: 'pending' | 'published' | 'rejected'
  created_at: string
  updated_at: string
  rejection_reason?: string
  distributor_id: string
}

export interface UpdateVacancyRequest {
  title?: string
  description?: string
  requirements?: string[]
  responsibilities?: string[]
  location?: string
  salary_range?: {
    min: number
    max: number
    currency: string
  }
  employment_type?: string
  experience_level?: string
  agent_reward?: number
  status?: 'pending' | 'published' | 'rejected'
  rejection_reason?: string
}